@@ -19,18 +19,21 @@ examples see the project pages at
 https://github.com/robotframework/PythonLibCore
 """
 import inspect
+import json
 import os
 from dataclasses import dataclass
-from typing import Any, Callable, List, Optional, get_type_hints
+from pathlib import Path
+from typing import Any, Callable, List, Optional, Union, get_type_hints
 
-from robot.api.deco import keyword  # noqa F401
+from robot.api import logger
+from robot.api.deco import keyword  # noqa: F401
 from robot.errors import DataError
-from robot.utils import Importer  # noqa F401
+from robot.utils import Importer
 
-__version__ = "4.1.2"
+__version__ = "4.4.1"
 
 
-class PythonLibCoreException(Exception):
+class PythonLibCoreException(Exception):  # noqa: N818
     pass
 
 
@@ -38,28 +41,69 @@ class PluginError(PythonLibCoreException):
     pass
 
 
+class NoKeywordFound(PythonLibCoreException):
+    pass
+
+
+def _translation(translation: Optional[Path] = None):
+    if translation and isinstance(translation, Path) and translation.is_file():
+        with translation.open("r") as file:
+            try:
+                return json.load(file)
+            except json.decoder.JSONDecodeError:
+                logger.warn(f"Could not convert json file {translation} to dictionary.")
+                return {}
+    else:
+        return {}
+
+
+def _translated_keywords(translation_data: dict) -> list:
+    return [item.get("name") for item in translation_data.values() if item.get("name")]
+
+
 class HybridCore:
-    def __init__(self, library_components):
+    def __init__(self, library_components: List, translation: Optional[Path] = None) -> None:
         self.keywords = {}
         self.keywords_spec = {}
         self.attributes = {}
-        self.add_library_components(library_components)
-        self.add_library_components([self])
+        translation_data = _translation(translation)
+        translated_kw_names = _translated_keywords(translation_data)
+        self.add_library_components(library_components, translation_data, translated_kw_names)
+        self.add_library_components([self], translation_data, translated_kw_names)
         self.__set_library_listeners(library_components)
 
-    def add_library_components(self, library_components):
-        self.keywords_spec["__init__"] = KeywordBuilder.build(self.__init__)
+    def add_library_components(
+        self,
+        library_components: List,
+        translation: Optional[dict] = None,
+        translated_kw_names: Optional[list] = None,
+    ):
+        translation = translation if translation else {}
+        translated_kw_names = translated_kw_names if translated_kw_names else []
+        self.keywords_spec["__init__"] = KeywordBuilder.build(self.__init__, translation)  # type: ignore
+        self.__replace_intro_doc(translation)
         for component in library_components:
             for name, func in self.__get_members(component):
                 if callable(func) and hasattr(func, "robot_name"):
                     kw = getattr(component, name)
-                    kw_name = func.robot_name or name
+                    kw_name = self.__get_keyword_name(func, name, translation, translated_kw_names)
                     self.keywords[kw_name] = kw
-                    self.keywords_spec[kw_name] = KeywordBuilder.build(kw)
+                    self.keywords_spec[kw_name] = KeywordBuilder.build(kw, translation)
                     # Expose keywords as attributes both using original
                     # method names as well as possible custom names.
                     self.attributes[name] = self.attributes[kw_name] = kw
 
+    def __get_keyword_name(self, func: Callable, name: str, translation: dict, translated_kw_names: list):
+        if name in translated_kw_names:
+            return name
+        if name in translation and translation[name].get("name"):
+            return translation[name].get("name")
+        return func.robot_name or name
+
+    def __replace_intro_doc(self, translation: dict):
+        if "__intro__" in translation:
+            self.__doc__ = translation["__intro__"].get("doc", "")
+
     def __set_library_listeners(self, library_components: list):
         listeners = self.__get_manually_registered_listeners()
         listeners.extend(self.__get_component_listeners([self, *library_components]))
@@ -80,13 +124,17 @@ class HybridCore:
         if inspect.ismodule(component):
             return inspect.getmembers(component)
         if inspect.isclass(component):
+            msg = f"Libraries must be modules or instances, got class '{component.__name__}' instead."
             raise TypeError(
-                "Libraries must be modules or instances, got " "class {!r} instead.".format(component.__name__)
+                msg,
             )
         if type(component) != component.__class__:
+            msg = (
+                "Libraries must be modules or new-style class instances, "
+                f"got old-style class {component.__class__.__name__} instead."
+            )
             raise TypeError(
-                "Libraries must be modules or new-style class "
-                "instances, got old-style class {!r} instead.".format(component.__class__.__name__)
+                msg,
             )
         return self.__get_members_from_instance(component)
 
@@ -100,7 +148,10 @@ class HybridCore:
     def __getattr__(self, name):
         if name in self.attributes:
             return self.attributes[name]
-        raise AttributeError("{!r} object has no attribute {!r}".format(type(self).__name__, name))
+        msg = "{!r} object has no attribute {!r}".format(type(self).__name__, name)
+        raise AttributeError(
+            msg,
+        )
 
     def __dir__(self):
         my_attrs = super().__dir__()
@@ -123,6 +174,9 @@ class DynamicCore(HybridCore):
 
     def get_keyword_arguments(self, name):
         spec = self.keywords_spec.get(name)
+        if not spec:
+            msg = f"Could not find keyword: {name}"
+            raise NoKeywordFound(msg)
         return spec.argument_specification
 
     def get_keyword_tags(self, name):
@@ -132,6 +186,9 @@ class DynamicCore(HybridCore):
         if name == "__intro__":
             return inspect.getdoc(self) or ""
         spec = self.keywords_spec.get(name)
+        if not spec:
+            msg = f"Could not find keyword: {name}"
+            raise NoKeywordFound(msg)
         return spec.documentation
 
     def get_keyword_types(self, name):
@@ -142,7 +199,7 @@ class DynamicCore(HybridCore):
 
     def __get_keyword(self, keyword_name):
         if keyword_name == "__init__":
-            return self.__init__
+            return self.__init__  # type: ignore
         if keyword_name.startswith("__") and keyword_name.endswith("__"):
             return None
         method = self.keywords.get(keyword_name)
@@ -181,13 +238,25 @@ class DynamicCore(HybridCore):
 
 class KeywordBuilder:
     @classmethod
-    def build(cls, function):
+    def build(cls, function, translation: Optional[dict] = None):
+        translation = translation if translation else {}
         return KeywordSpecification(
             argument_specification=cls._get_arguments(function),
-            documentation=inspect.getdoc(function) or "",
+            documentation=cls.get_doc(function, translation),
             argument_types=cls._get_types(function),
         )
 
+    @classmethod
+    def get_doc(cls, function, translation: dict):
+        if kw := cls._get_kw_transtation(function, translation):  # noqa: SIM102
+            if "doc" in kw:
+                return kw["doc"]
+        return inspect.getdoc(function) or ""
+
+    @classmethod
+    def _get_kw_transtation(cls, function, translation: dict):
+        return translation.get(function.__name__, {})
+
     @classmethod
     def unwrap(cls, function):
         return inspect.unwrap(function)
@@ -203,11 +272,19 @@ class KeywordBuilder:
         return argument_specification
 
     @classmethod
-    def _get_arg_spec(cls, function: Callable):
+    def _get_arg_spec(cls, function: Callable) -> inspect.FullArgSpec:
         return inspect.getfullargspec(function)
 
     @classmethod
-    def _get_args(cls, arg_spec: inspect.FullArgSpec, function: Callable):
+    def _get_type_hint(cls, function: Callable):
+        try:
+            hints = get_type_hints(function)
+        except Exception:  # noqa: BLE001
+            hints = function.__annotations__
+        return hints
+
+    @classmethod
+    def _get_args(cls, arg_spec: inspect.FullArgSpec, function: Callable) -> list:
         args = cls._drop_self_from_args(function, arg_spec)
         args.reverse()
         defaults = list(arg_spec.defaults) if arg_spec.defaults else []
@@ -221,7 +298,11 @@ class KeywordBuilder:
         return formated_args
 
     @classmethod
-    def _drop_self_from_args(cls, function: Callable, arg_spec: inspect.FullArgSpec):
+    def _drop_self_from_args(
+        cls,
+        function: Callable,
+        arg_spec: inspect.FullArgSpec,
+    ) -> list:
         return arg_spec.args[1:] if inspect.ismethod(function) else arg_spec.args
 
     @classmethod
@@ -234,11 +315,11 @@ class KeywordBuilder:
 
     @classmethod
     def _get_named_only_args(cls, arg_spec: inspect.FullArgSpec) -> list:
-        rf_spec = []
+        rf_spec: list = []
         kw_only_args = arg_spec.kwonlyargs if arg_spec.kwonlyargs else []
         if not arg_spec.varargs and kw_only_args:
             rf_spec.append("*")
-        kw_only_defaults = arg_spec.kwonlydefaults if arg_spec.kwonlydefaults else []
+        kw_only_defaults = arg_spec.kwonlydefaults if arg_spec.kwonlydefaults else {}
         for kw_only_arg in kw_only_args:
             if kw_only_arg in kw_only_defaults:
                 rf_spec.append((kw_only_arg, kw_only_defaults[kw_only_arg]))
@@ -258,22 +339,18 @@ class KeywordBuilder:
     @classmethod
     def _get_typing_hints(cls, function):
         function = cls.unwrap(function)
-        try:
-            hints = get_type_hints(function)
-        except Exception:
-            hints = function.__annotations__
+        hints = cls._get_type_hint(function)
         arg_spec = cls._get_arg_spec(function)
         all_args = cls._args_as_list(function, arg_spec)
         for arg_with_hint in list(hints):
-            # remove return and self statements
-            if arg_with_hint not in all_args:
+            # remove self statements
+            if arg_with_hint not in [*all_args, "return"]:
                 hints.pop(arg_with_hint)
         return hints
 
     @classmethod
-    def _args_as_list(cls, function, arg_spec):
-        function_args = []
-        function_args.extend(cls._drop_self_from_args(function, arg_spec))
+    def _args_as_list(cls, function, arg_spec) -> list:
+        function_args = cls._drop_self_from_args(function, arg_spec)
         if arg_spec.varargs:
             function_args.append(arg_spec.varargs)
         function_args.extend(arg_spec.kwonlyargs or [])
@@ -290,18 +367,23 @@ class KeywordBuilder:
 
 
 class KeywordSpecification:
-    def __init__(self, argument_specification=None, documentation=None, argument_types=None):
+    def __init__(
+        self,
+        argument_specification=None,
+        documentation=None,
+        argument_types=None,
+    ) -> None:
         self.argument_specification = argument_specification
         self.documentation = documentation
         self.argument_types = argument_types
 
 
 class PluginParser:
-    def __init__(self, base_class: Optional[Any] = None, python_object: List[Any] = []):
+    def __init__(self, base_class: Optional[Any] = None, python_object=None) -> None:
         self._base_class = base_class
-        self._python_object = python_object
+        self._python_object = python_object if python_object else []
 
-    def parse_plugins(self, plugins: str) -> List:
+    def parse_plugins(self, plugins: Union[str, List[str]]) -> List:
         imported_plugins = []
         importer = Importer("test library")
         for parsed_plugin in self._string_to_modules(plugins):
@@ -320,13 +402,12 @@ class PluginParser:
     def get_plugin_keywords(self, plugins: List):
         return DynamicCore(plugins).get_keyword_names()
 
-    def _string_to_modules(self, modules):
-        parsed_modules = []
+    def _string_to_modules(self, modules: Union[str, List[str]]):
+        parsed_modules: list = []
         if not modules:
             return parsed_modules
-        for module in modules.split(","):
-            module = module.strip()
-            module_and_args = module.split(";")
+        for module in self._modules_splitter(modules):
+            module_and_args = module.strip().split(";")
             module_name = module_and_args.pop(0)
             kw_args = {}
             args = []
@@ -336,6 +417,13 @@ class PluginParser:
                     kw_args[key] = value
                 else:
                     args.append(argument)
-            module = Module(module=module_name, args=args, kw_args=kw_args)
-            parsed_modules.append(module)
+            parsed_modules.append(Module(module=module_name, args=args, kw_args=kw_args))
         return parsed_modules
+
+    def _modules_splitter(self, modules: Union[str, List[str]]):
+        if isinstance(modules, str):
+            for module in modules.split(","):
+                yield module
+        else:
+            for module in modules:
+                yield module
